diff --git a/replicate.module b/replicate.module
index b43ca0d..75d92dc 100644
--- a/replicate.module
+++ b/replicate.module
@@ -45,6 +45,8 @@ function replicate_entity($entity_type, $entity) {
     list($entity_id) = entity_extract_ids($entity_type, $clone);
 
     if (isset($entity_id)) {
+      module_invoke_all('replicate_entity_after_save', $clone, $entity_type, $entity);
+
       return $entity_id;
     }
   }

diff --git a/replicate.api.php b/replicate.api.php
index b00b643..380815e 100644
--- a/replicate.api.php
+++ b/replicate.api.php
@@ -23,11 +23,11 @@ function hook_replicate_entity_ENTITY_TYPE(&$replica) {
 }
 
 /**
  * Alter the replica before returning it.
  *
  * This hook is called at the end of the operations
  * of replicate_clone_entity() function, allowing to alter the replicate
- * before it is return to the caller. This function will apply to all
+ * before it is returned to the caller. This function will apply to all
  * replicated entities.
  *
  * @param object $replica
@@ -49,6 +49,35 @@ function hook_replicate_entity_alter(&$replica, $entity_type, $original) {
 }
 
 /**
+ * Alter the replica right after it has been saved.
+ *
+ * This hook is called at the end of the operations
+ * of replicate_entity() (and so replicate_entity_by_id) function, allowing to
+ * alter the replicate before it is returned to the caller. This function will
+ * not apply to replication directly using replicate_clone_entity and
+ * replicate_clone_entity_by_id as these functions don't save entities.
+ *
+ * This hook is meant to be used to trigger other actions, not modifying the
+ * replicated entity. For that use hook_replicate_entity_alter().
+ *
+ * @param object $replica
+ *   Reference to the fully loaded entity object being saved (the clone) that
+ *   can be altered as needed.
+ * @param string $entity_type
+ *   Type of the entity containing the field.
+ * @param object $original
+ *   The fully loaded original entity object.
+ *
+ * @see replicate_clone_entity()
+ * @see drupal_alter()
+ */
+function hook_replicate_entity_after_save($replica, $entity_type, $original) {
+  // Do something common to all entities that are replicated.
+  $wrapper = entity_metadata_wrapper($entity_type, $replica);
+  $wrapper->field_is_replica->set(TRUE);
+}
+
+/**
  * Manage the replication of a specific field type.
  *
  * May be used to manage the replication of custom field type,
@@ -23,11 +23,11 @@ function hook_replicate_entity_ENTITY_TYPE(&$replica) {
 
 /**
- * Alter the replica before returning it.
+ * Alter the replica before returning it (and before entity is saved).
  *
  * This hook is called at the end of the operations